BOOST_PP_WHILE_d_macros

This is a list, based on functionality, of the macros which have an alternate _d name, representing a reentry into the BOOST_PP_WHILE looping construct:
arithmetic

- BOOST_PP_ADD_D
- BOOST_PP_DIV_D
- BOOST_PP_MOD_D
- BOOST_PP_MUL_D
- BOOST_PP_SUB_D

array

- BOOST_PP_ARRAY_INSERT_D
- BOOST_PP_ARRAY_REMOVE_D
- BOOST_PP_ARRAY_REPLACE_D

comparison

- BOOST_PP_GREATER_D
- BOOST_PP_GREATER_EQUAL_D
- BOOST_PP_LESS_D
- BOOST_PP_LESS_EQUAL_D

control

- BOOST_PP_DEDUCE_D

list

- BOOST_PP_LIST_APPEND_D
- BOOST_PP_LIST_AT_D
- BOOST_PP_LIST_CAT_D
- BOOST_PP_LIST_FILTER_D
- BOOST_PP_LIST_FIRST_N_D
- BOOST_PP_LIST_FOLD_LEFT_d
- BOOST_PP_LIST_FOLD_RIGHT_d
- BOOST_PP_LIST_REST_N_D
- BOOST_PP_LIST_REVERSE_D
- BOOST_PP_LIST_TO_ARRAY_D
- BOOST_PP_LIST_TRANSFORM_D

selection

- BOOST_PP_MAX_D
- BOOST_PP_MIN_D

repetition

- BOOST_PP_REPEAT_FROM_TO_D
- BOOST_PP_REPEAT_FROM_TO_D_z

tuple

- BOOST_PP_TUPLE_INSERT_D
- BOOST_PP_TUPLE_REMOVE_D
- BOOST_PP_TUPLE_REPLACE_D

base

- BOOST_PP_WHILE_D

© Copyright Edward Diener 2014

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)